@@ -1,11 +1,11 @@
-require 'debci/auth_app'
+require 'debci/app'
 require 'debci/user'
 require 'debci/package'
 require 'debci/job'
 require 'debci/html_helpers'
 
 module Debci
-  class Admin < Debci::AuthApp
+  class Admin < Debci::App
     include Debci::HTMLHelpers
     set :views, "#{File.dirname(__FILE__)}/html/templates"
 
@@ -90,16 +90,22 @@ module Debci
 
     post '/:model/new/' do
       forbidden unless current_model_info.new
-      save_object(current_model.new, params, [])
+      object = read_object(current_model.new, params, [])
+      object.save!
       redirect "/admin/#{current_model_name}/"
+    rescue ActiveRecord::RecordInvalid => e
+      erb :admin_edit, locals: { object: object, fields: fields, select_fields: select_fields, read_only_fields: [], validation_error: e }
     end
 
     post '/:model/:id/' do
-      save_object(current_object, params, read_only_fields)
+      read_object(current_object, params, read_only_fields)
+      current_object.save!
       redirect "/admin/#{current_model_name}/"
+    rescue ActiveRecord::RecordInvalid => e
+      erb :admin_edit, locals: { object: current_object, fields: fields, select_fields: select_fields, read_only_fields: read_only_fields, validation_error: e }
     end
 
-    def save_object(object, params, read_only_fields)
+    def read_object(object, params, read_only_fields)
       data = params.reject do |key, _value|
         [:model, :id].include?(key.to_sym) || read_only_fields.include?(key.to_sym)
       end
@@ -108,7 +114,8 @@ module Debci
         data[f] = nil if column.null && data[f].blank?
         data[f] = parse(f.to_sym, data[f]) if data[f]
       end
-      object.update!(data) # FIXME: handle validation failures
+      object.attributes = data
+      object
     end
 
     def current_model_name
@@ -157,7 +164,7 @@ module Debci
     end
 
     def parse_size(str)
-      n = str.to_i
+      n = str.to_f
       case str
       when /mb$/i
         n *= 1.megabyte
