@@ -5,18 +5,22 @@ require 'debci'
 module Debci
   module AMQP
     def self.get_queue(arch, backend = Debci.config.backend)
-      @queues ||= {}
-      @queues[arch] ||=
-        begin
-          opts = {
-            durable: true,
-            arguments: {
-              'x-max-priority': 10,
-            }
-          }
-          q = ENV['debci_amqp_queue'] || "debci-tests-#{arch}-#{backend}"
-          self.amqp_channel.queue(q, opts)
-        end
+      opts = {
+        durable: true,
+        arguments: {
+          'x-max-priority': 10,
+        }
+      }
+      q = ENV['debci_amqp_queue'] || queue_name(arch, backend)
+      self.amqp_channel.queue(q, opts)
+    end
+
+    def self.queue_exists?(arch, backend)
+      conn.queue_exists?(queue_name(arch, backend))
+    end
+
+    def self.queue_name(arch, backend)
+      "debci-tests-#{arch}-#{backend}"
     end
 
     def self.results_queue
@@ -24,11 +28,14 @@ module Debci
       self.amqp_channel.queue(q, durable: true)
     end
 
-    def self.amqp_channel
-      @conn ||= Bunny.new(Debci.config.amqp_server, amqp_options).tap do |conn|
-        conn.start
+    def self.conn
+      @conn ||= Bunny.new(Debci.config.amqp_server, amqp_options).tap do |c|
+        c.start
       end
-      @channel ||= @conn.create_channel
+    end
+
+    def self.amqp_channel
+      @channel ||= conn.create_channel
     end
 
     def self.amqp_options
