@@ -171,7 +171,7 @@ module Debci
 
       * `since`: UNIX timestamp; tells the API to only retrieve results that are
         newer then the given timestamp, i.e. jobs that were either created after
-        it, or finished after it.
+        it, or finished after it. This parameter is mandatory.
 
       Some test results may be returned in multiple calls to this endpoint that
       use different value of `since`. For example, while a test is still running,
@@ -233,6 +233,8 @@ module Debci
         if params[:since]
           since = Time.strptime(params[:since], '%s')
           jobs = jobs.where('created_at >= ? OR date >= ?', since, since)
+        else
+          halt(400, 'Missing parameter: since (UNIX timestamp)')
         end
         results = []
         fields = test_fields.keys.map(&:to_s)
@@ -242,7 +244,7 @@ module Debci
           end
         end
         data = {
-          until: jobs.map(&:created_at).max.to_i,
+          until: jobs.map { |job| [job.created_at, job.date, job.updated_at].compact.max }.max.to_i,
           results: results,
         }
         headers['Content-Type'] = 'application/json'
