@@ -31,6 +31,7 @@ module Debci
     :data_basedir,
     :data_retention_days,
     :database_url,
+    :disk_storage_limit,
     :distro_name,
     :failing_packages_per_page,
     :html_dir,
@@ -65,6 +66,7 @@ module Debci
         'quiet' => lambda { |x| x == 'true' }, # boolean
         'amqp_ssl' => lambda { |x| x == 'true' }, # boolean
         'data_retention_days' => lambda { |x| x.to_i },
+        'disk_storage_limit' => lambda { |x| x.to_i },
         'status_visible_days' => lambda { |x| x.to_i },
         'failing_packages_per_page' => lambda { |x| x.to_i },
         'slow_tests_duration_minutes' => lambda { |x| x.to_i }
