@@ -111,7 +111,10 @@ module Debci
       def load_job(data)
         job = Debci::Job.new
         job.package = Debci::Package.find_or_create_by!(name: data.delete("package"))
+        job.requestor = Debci::User.find_or_create_by!(username: "nobody")
         data.each do |attr, value|
+          next if attr =~ /_id$/
+
           job[attr] = value if job.attributes.key?(attr)
         end
         job.save!
