@@ -16,7 +16,11 @@ module Debci
     def self.migrate(target_version = nil)
       migrations_path = File.join(File.dirname(__FILE__), 'db', 'migrations')
       ActiveRecord::Migration.verbose = !Debci.config.quiet
-      if ActiveRecord.version.release >= Gem::Version.new('6.0')
+      if ActiveRecord.version.release >= Gem::Version.new('7.0')
+        pool = ActiveRecord::Base.connection_pool
+        migrations = ActiveRecord::MigrationContext.new(migrations_path).migrations
+        ActiveRecord::Migrator.new(:up, migrations, pool.schema_migration, pool.internal_metadata).migrate
+      elsif ActiveRecord.version.release >= Gem::Version.new('6.0')
         # ActiveRecord 6+
         ActiveRecord::MigrationContext.new(migrations_path, ActiveRecord::SchemaMigration).migrate(target_version)
       else
@@ -33,4 +37,13 @@ module Debci
   end
 end
 
+if ActiveRecord.version.release < Gem::Version.new('7.0')
+  class ActiveRecord::Base
+    def self.serialize(field, **options)
+      type = options.delete(:type)
+      super(field, type, **options)
+    end
+  end
+end
+
 Debci::DB.establish_connection
