@@ -21,8 +21,7 @@ module Debci
       jobs = Debci::Job.where(['date >= ? AND date <= ?', start_date, expire_date])
       jobs.in_batches.each do |subset|
         subset.each do |job|
-          job.cleanup
-          Debci.log('Cleaned up files for job %<job_id>s (%<job>s)' % { job_id: job.run_id, job: job })
+          job.cleanup(reason: "past data retention period")
         end
       end
 
