@@ -1,6 +1,6 @@
 module Debci
   class ExtraAptSource
-    attr_reader :entry
+    attr_reader :entry, :signing_key
 
     def initialize(entry, allowed_users = [], signing_key = nil)
       @entry = entry
