@@ -4,7 +4,9 @@ require 'debci/package'
 module Debci
   class Home < Debci::App
     get '/' do
-      @package_prefixes = Debci::Package.prefixes
+      halt(erb(:no_public_browsing)) unless logged_in?
+
+      @package_prefixes = Debci::Package.prefixes if logged_in?
       erb :index
     end
   end
