@@ -91,7 +91,13 @@ module Debci
 
       def packages
         p = root / suite / arch / 'packages.json'
-        p.write(::JSON.pretty_generate(status_packages_data.map(&:job).as_json))
+        data = []
+        status_packages_data.includes(job: :package).in_batches do |batch|
+          batch.each do |status|
+            data << status.job.public_api_attributes
+          end
+        end
+        p.write(::JSON.pretty_generate(data.as_json))
       end
     end
   end
