@@ -1,6 +1,7 @@
 require 'erb'
 require 'active_support'
 require 'active_support/core_ext'
+require 'ansi/bbcode'
 
 module Debci
   module HTMLHelpers
@@ -61,8 +62,12 @@ module Debci
       end.flatten
     end
 
+    def pkg_history_url(package, suite, arch)
+      "/packages/#{package.prefix}/#{package.name}/#{suite}/#{arch}/"
+    end
+
     def history_url(job)
-      "/packages/#{job.package.prefix}/#{job.package.name}/#{job.suite}/#{job.arch}/"
+      pkg_history_url(job.package, job.suite, job.arch)
     end
 
     def package_url(package)
@@ -73,5 +78,22 @@ module Debci
     def expand_url(url, suite)
       url&.gsub('{SUITE}', suite)
     end
+
+    # Converts ANSI codes to HTML. Escapes any HTML before even looking for
+    # ANSI codes.
+    def ansi_to_html(str)
+      return str unless str
+      input = str.gsub(/</, '&lt;').gsub(/>/, '&gt;')
+      return input unless input =~ /\e\[/
+      begin
+        result = ANSI::BBCode.ansi_to_html(input)
+        result = result[0..-8] if result =~ %r{<br />\n$}
+        result
+      rescue StandardError
+        # in case anything goes wrong with the conversion, just remove all ANSI
+        # escape codes
+        input.gsub(/\e\[[0-9;]+m/, "")
+      end
+    end
   end
 end
