@@ -35,7 +35,6 @@ module Debci
     def parse
       section = nil
       subsection = nil
-      result = false
       file = File.open(@input)
       if @input =~ /\.gz/
         file = Zlib::GzipReader.new(file)
@@ -58,7 +57,6 @@ module Debci
           subsection = Section.new("test run")
         when /^\s*\d+s autopkgtest \[[0-9:]+\]: test (\S+):  - - - - - - - - - - results - - - - - - - - - -/
           subsection = Section.new("test results")
-          result = true
         when /^\s*\d+s autopkgtest \[\d\d:\d\d:\d\d\]: @@@@@@@@@@@@@@@@@@@@ (summary)/
           section = Section.new("Closing")
           subsection = Section.new("summary")
@@ -81,9 +79,8 @@ module Debci
         end
         subsection.output << line if subsection
 
-        if section && result && line =~ /^\s*\d+s\s+\S+\s*(PASS|FAIL|SKIP)/
+        if section && line =~ /^\s*\d+s\s+\S+\s*(PASS|FAIL|SKIP)/
           section.result = ::Regexp.last_match(1).downcase
-          result = false
         end
       end
     end
