@@ -100,6 +100,12 @@ describe Debci::Admin do
         pkg.reload
         expect(pkg.storage_limit).to eq(1.gigabyte)
       end
+      it 'supports fractionary numbers' do
+        pkg = Debci::Package.create!(name: "foobar")
+        post "/admin/packages/#{pkg.id}/", storage_limit: '1.5 GB'
+        pkg.reload
+        expect(pkg.storage_limit).to eq(1.5.gigabyte)
+      end
     end
   end
 end
