@@ -58,6 +58,18 @@ describe Debci::API do
     end
   end
 
+  context 'serving documentation' do
+    it 'redirects root to the documentation' do
+      get "/api"
+      expect(last_response.status).to eq(302)
+      expect(last_response.location).to match(%r{/api/doc$})
+    end
+    it 'serves the documentation' do
+      get "/api/doc"
+      expect(last_response.status).to eq(200)
+    end
+  end
+
   context 'receiving test requests' do
     before do
       key = Debci::Key.create!(user: theuser).key
@@ -312,7 +324,7 @@ describe Debci::API do
         arch: arch,
         requestor: theuser,
       )
-      get '/api/v1/test'
+      get '/api/v1/test', since: Time.now - 1.hour
       data = JSON.parse(last_response.body)
       expect(data["results"].first["run_id"]).to eq(job.run_id)
       expect(data["results"].first["package"]).to eq("mypackage")
@@ -357,7 +369,7 @@ describe Debci::API do
         requestor: theuser,
         created_at: Time.now - 1.hour
       )
-      get '/api/v1/test'
+      get '/api/v1/test', since: Time.now - 1.hour
       ids = JSON.parse(last_response.body)["results"].map { |e| e["run_id"] }
       expect(ids).to eq([job1.run_id, job2.run_id])
     end
@@ -459,4 +471,11 @@ describe Debci::API do
       end
     end
   end
+
+  context 'handling not found' do
+    it 'returns a valid 404 respose' do
+      get 'api/v1/something-invalid'
+      expect(last_response.status).to eq(404)
+    end
+  end
 end
