@@ -24,8 +24,7 @@ describe Debci::Collector do
     allow_any_instance_of(Debci::Config).to receive(:autopkgtest_basedir).and_return(File.join(tmpdir, "autopkgtest"))
   end
 
-  it 'receives payload, updates database and HTML' do
-    expect(Debci::HTML).to receive(:update_package).with(package)
+  it 'receives payload, updates database' do
     collector.receive_payload(tmpdir, payload)
     job.reload
     expect(job.status).to eq('pass')
@@ -43,7 +42,7 @@ describe Debci::Collector do
     collector.receive_payload('/path/to/unexistig/directory', payload)
   end
 
-  it 'handles and empty results tarball' do
+  it 'handles an empty results tarball' do
     empty_tarball = IO.popen(['tar', '-czf', '-', '-T', '/dev/null']).read
     collector.receive_payload(tmpdir, empty_tarball)
   end
