@@ -21,7 +21,7 @@ describe Debci::Config do
       it "knows about #{key}" do
         expect(config.send(key)).to_not be_a(String)
       end
-    elsif [:data_retention_days, :failing_packages_per_page, :status_visible_days, :slow_tests_duration_minutes].include?(key)
+    elsif [:data_retention_days, :disk_storage_limit, :failing_packages_per_page, :status_visible_days, :slow_tests_duration_minutes].include?(key)
       it "knows about #{key}" do
         expect(config.send(key)).to be_a(Integer)
       end
