@@ -96,7 +96,10 @@ describe Debci::Data::Import do
     expect(Debci::Job.count).to eq(1)
     job = Debci::Job.first
     expect(job.package).to eq(package)
-    job_data.reject { |k, _v| [:run_id, :package].include?(k) }.each do |k, v|
+    fields = job_data.except(:run_id, :package)
+    fields.each do |k, v|
+      next if k.to_sym == :requestor
+
       expect(job.send(k)).to eq(v)
     end
   end
