@@ -4,7 +4,7 @@ require 'rack/test'
 require 'debci/home'
 
 describe Debci::Home do
-  include Rack::Test::Methods
+  include WebAppHelper
 
   class Home < Debci::Home
     set :raise_errors, true
@@ -16,6 +16,7 @@ describe Debci::Home do
   end
 
   it 'renders the home page with no data' do
+    fake_login("someone")
     get '/'
     expect(last_response.status).to eq(200)
     expect(last_response.body).to match("(no data yet)")
@@ -23,8 +24,21 @@ describe Debci::Home do
 
   it 'renders the home page with packages' do
     Debci::Package.create!(name: "foobar")
+    fake_login("someone")
     get '/'
     expect(last_response.status).to eq(200)
-    expect(last_response.body).to_not match("(no data yet)")
+    expect(last_response.body).to match('"/packages/f"')
+  end
+
+  it 'does not allow browsing packages without a login' do
+    Debci::Package.create!(name: "foobar")
+    get '/'
+    expect(last_response.status).to eq(200)
+    expect(last_response.body).to_not match('"/packages/f"')
+  end
+
+  it 'does not provide a session cookie without a login' do
+    get '/'
+    expect(last_response.headers).to_not have_key('set-cookie')
   end
 end
