@@ -62,4 +62,23 @@ describe Debci::HTMLHelpers do
       expect(expand_pin_packages(test)).to be_an(Array)
     end
   end
+
+  context 'handling ANSI escape codes' do
+    it 'escapes HTML' do
+      expect(ansi_to_html("<span></span>")).to eq("&lt;span&gt;&lt;/span&gt;")
+    end
+
+    it 'converts ANSI to HTML' do
+      expect(ansi_to_html("\e[0;32m.\e[0m")).to eq("<font color=\"green\">.</font>")
+    end
+
+    it 'returns nil untouched' do
+      expect(ansi_to_html(nil)).to be_nil
+    end
+
+    it 'strips ANSI codes off if anything goes wrong with the conversion' do
+      expect(ANSI::BBCode).to receive(:ansi_to_html).and_raise(RuntimeError)
+      expect(ansi_to_html("\e[0;31mCRASH")).to eq("CRASH")
+    end
+  end
 end
