@@ -320,12 +320,14 @@ describe Debci::Job do
       File.join(tmpdir, 'autopkgtest-incoming', original_job.id.to_s)
     end
 
-    let(:past) { Time.now - 7.days }
+    let(:now) { Time.now }
+    let(:past) { now - 7.days }
     before(:each) do
       FileUtils.mkdir_p File.dirname(incoming)
       FileUtils.cp_r 'spec/debci/job_spec/autopkgtest-incoming', incoming
       FileUtils.touch(File.join(incoming, 'duration'), mtime: past)
       allow_any_instance_of(Debci::Config).to receive(:autopkgtest_basedir).and_return(File.join(tmpdir, 'autopkgtest'))
+      allow(Time).to receive(:now).and_return(now)
     end
     let(:job) do
       Debci::Job.receive(incoming)
@@ -343,6 +345,7 @@ describe Debci::Job do
     it('gets message') { expect(job.message).to eq('All tests passed') }
     it('gets duration') { expect(job.duration_seconds).to eq(9) }
     it('gets date') { expect(job.date).to eq(past) }
+    it('sets updated_at') { expect(job.updated_at).to eq(now) }
     it('gets version') { expect(job.version).to eq('1.0-1') }
     it 'moves directory into autopkgtest dir' do
       id = job.id.to_s
