@@ -131,9 +131,19 @@ describe Debci::Package do
     end
   end
 
-  it 'can have a storage limit' do
-    pkg = Debci::Package.new
-    expect(pkg.storage_limit).to be_nil
-    pkg.storage_limit = 1.gigabyte
+  context 'recording a storage limit' do
+    it 'has a storage limit' do
+      pkg = Debci::Package.new
+      expect(pkg.storage_limit).to be_nil
+      pkg.storage_limit = 1.gigabyte
+    end
+
+    it 'supports values > 2GB' do
+      Debci::Package.create!(name: "mypkg", storage_limit: 3.gigabytes)
+    end
+
+    it 'requires a non-zero number' do
+      expect { Debci::Package.create!(name: "mypkg", storage_limit: 0) }.to raise_error(ActiveRecord::RecordInvalid)
+    end
   end
 end
