@@ -68,6 +68,37 @@ describe Debci::SelfService do
       get '/user/foo@bar.com/jobs'
       expect(last_response.body).to match('Welcome foo@bar.com')
     end
+    it 'redirects to the original URL' do
+      get "/user/:user/retry/1"
+      follow_redirect!
+      expect(last_request.path).to eq("/user/login")
+      login("foobar")
+      follow_redirect!
+      expect(last_request.path).to eq("/user/:user/retry/1")
+    end
+    it 'redirects to the original URL from the query' do
+      get "/user", original_url: "/"
+      follow_redirect!
+      expect(last_request.path).to eq("/user/login")
+      login("foobar")
+      follow_redirect!
+      expect(last_request.path).to eq("/")
+    end
+    it 'does not show login page to logged in users' do
+      login("foobar")
+      get("/user/login")
+      follow_redirect!
+      expect(last_request.path).to_not eq("/user/login")
+    end
+  end
+
+  context 'explicit login' do
+    it 'redirects to the original URL' do
+      get "/user/login", original_url: "/"
+      login("foobar")
+      follow_redirect!
+      expect(last_request.path).to eq("/")
+    end
   end
 
   context 'request test form' do
