@@ -93,4 +93,24 @@ describe Debci::StorageLimit do
       expect(package.jobs.where(files_purged: true).count).to eq(0)
     end
   end
+
+  context 'CLI' do
+    before(:each) do
+      create_jobs_exceeding_the_limit(package)
+      package.storage_limit = 1.gigabyte
+      package.save!
+    end
+
+    let(:cli) { Debci::StorageLimit::CLI.new }
+
+    it 'lists packages' do
+      expect(cli).to receive(:tp)
+      cli.list
+    end
+
+    it 'cleans up package' do
+      expect_any_instance_of(Debci::StorageLimit).to receive(:cleanup_package)
+      cli.cleanup(package.name)
+    end
+  end
 end
