@@ -89,6 +89,10 @@ OmniAuth.config.test_mode = true
 module WebAppHelper
   include Rack::Test::Methods
 
+  def fake_login(username)
+    env("rack.session", { :user_id => Debci::User.create!(username: username).id })
+  end
+
   def login(username, uid = nil)
     uid ||= username.hash % 1000
     OmniAuth.config.mock_auth[:gitlab] = OmniAuth::AuthHash.new({
@@ -98,4 +102,8 @@ module WebAppHelper
     })
     get '/user/auth/gitlab/callback'
   end
+
+  def logout
+    env("rack.session", {})
+  end
 end
