@@ -25,4 +25,13 @@ test_truncates_large_logs() {
   assertTrue "log is smaller than 21MB" "[ $size -lt $upper_limit ]"
 }
 
+test_limits_size_of_artifacts_directory() {
+  (cd test/test-package-large-artifacts/ && debci test --run-id 1 --backend null .) # >/dev/null 2>&1)
+  output="$debci_data_basedir/autopkgtest-incoming/unstable/${debci_arch}/t/test-package-large-artifacts/1"
+  size=$(du -sm "${output}"/artifacts | awk '{print($1)}')
+  assertTrue "there are artifacts" "[ $size -gt 1 ]"
+  assertTrue "artifacts are less than 100MB" "[ $size -le 100 ]"
+  assertTrue "message left about file removal" "grep 'directory was too large.' ${output}/artifacts/*.removed.txt"
+}
+
 . shunit2
