@@ -47,12 +47,6 @@ submit_tests() {
   debci-enqueue $(cat ${debci_config_dir}/seed_list)
 }
 
-status_dir_for_package() {
-  local pkg="$1"
-  pkg_dir=$(echo "$pkg" | sed -e 's/\(\(lib\)\?.\).*/\1\/&/')
-  echo "${debci_data_basedir}/packages/unstable/${debci_arch}/${pkg_dir}"
-}
-
 autopkgtest_dir_for_package() {
   local pkg="$1"
   pkg_dir=$(echo "$pkg" | sed -e 's/\(\(lib\)\?.\).*/\1\/&/')
