@@ -27,4 +27,9 @@ if [ ! -f $configdir/conf.d/dev.conf ]; then
   echo "debci_backend=fake" >> $configdir/conf.d/dev.conf
 fi
 
+if [ ! -f $configdir/conf.d/secret.conf ]; then
+  echo "debci_session_secret=$(openssl rand -hex 32)" \
+    > $configdir/conf.d/secret.conf
+fi
+
 ./bin/debci migrate
